@@ -114,10 +114,6 @@ def strip_multiple_choice_msg(help_text):
     return help_text.replace(multiple_choice_msg, '')
 
 
-class IgnoreFieldException(Exception):
-    pass
-
-
 class Field(object):
     read_only = True
     creation_counter = 0
@@ -305,6 +301,11 @@ class WritableField(Field):
         result.validators = self.validators[:]
         return result
 
+    def get_default_value(self):
+        if is_simple_callable(self.default):
+            return self.default()
+        return self.default
+
     def validate(self, value):
         if value in validators.EMPTY_VALUES and self.required:
             raise ValidationError(self.error_messages['required'])
@@ -329,7 +330,7 @@ class WritableField(Field):
 
     def field_to_native(self, obj, field_name):
         if self.write_only:
-            raise IgnoreFieldException()
+            return None
         return super(WritableField, self).field_to_native(obj, field_name)
 
     def field_from_native(self, data, files, field_name, into):
@@ -353,10 +354,7 @@ class WritableField(Field):
         except KeyError:
             if self.default is not None and not self.partial:
                 # Note: partial updates shouldn't set defaults
-                if is_simple_callable(self.default):
-                    native = self.default()
-                else:
-                    native = self.default
+                native = self.get_default_value()
             else:
                 if self.required:
                     raise ValidationError(self.error_messages['required'])
@@ -481,7 +479,8 @@ class URLField(CharField):
     type_label = 'url'
 
     def __init__(self, **kwargs):
-        kwargs['validators'] = [validators.URLValidator()]
+        if not 'validators' in kwargs:
+            kwargs['validators'] = [validators.URLValidator()]
         super(URLField, self).__init__(**kwargs)
 
 
